@@ -199,3 +199,9 @@ class connector:
 		body = None
 		data = self.patch(url, body=body)
 		return (data)
+
+	def get_level(self, login):
+		url = f"/users/{login}/cursus_users?filter[cursus_id]=21"
+		data = self.get(url)
+		return (data['level'])
+
